Learn R Programming

edfinr (version 0.1.1)

list_variables: List available variables in the education finance dataset

Description

This function provides information about the variables available in the education finance dataset, including their names, types, and brief descriptions.

Usage

list_variables(dataset_type = "skinny", category = "all")

Value

A tibble with variable information

Arguments

dataset_type

A string specifying whether to list variables for "skinny" (default) or "full" dataset.

category

Optional. Filter variables by category: "id", "time", "geographic", "demographic", "revenue", "expenditure", "economic", "governance", or "all" (default).

Examples

Run this code
# list all available variables in skinny dataset
vars <- list_variables()
head(vars)

# list all variables in full dataset
full_vars <- list_variables(dataset_type = "full")
nrow(full_vars)

# list only expenditure variables in full dataset
exp_vars <- list_variables(dataset_type = "full", category = "expenditure")
head(exp_vars)

Run the code above in your browser using DataLab